AfHelperService class

Constructors

AfHelperService({required AfHelperConfig config, Client? httpClient})

Properties

appsflyerId String?
no setter
config AfHelperConfig
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

cacheCompatible() Future<void>
clearCache() Future<void>
initAppsFlyer() Future<void>
loadImage() Future<Uint8List?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
performCheck() Future<AfHelperCheckOutcome>
toString() String
A string representation of this object.
inherited
waitForConversionData() Future<Map<String, dynamic>?>

Operators

operator ==(Object other) bool
The equality operator.
inherited